PCB Environment: ObjectPtrNameLessThan Class Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions
ObjectPtrNameLessThan Class Reference

## Public Member Functions
bool | operator() (const Object *L, const Object *R) const
| Parent names take precedent, no parent counts as less.

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/UI/Actions.hpp